@@ -1,6 +1,12 @@
+from nose.plugins.skip import SkipTest
+from wtforms import __version__ as wtforms_version
+
+if int(wtforms_version[0]) < 2:
+    raise SkipTest('MongoEngine does not support WTForms 1.')
+
 from flask import Flask
-from flask.ext.admin import Admin
-from flask.ext.mongoengine import MongoEngine
+from flask_admin import Admin
+from flask_mongoengine import MongoEngine
 
 
 def setup():
